<?php

namespace Drupal\log_cache_tags\Form;

use Drupal\Core\Form\FormInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Messenger\MessengerTrait;
use Drupal\Core\State\StateInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides the Log Cache Tags settings form.
 */
class LogCacheTagsForm implements FormInterface {

  use MessengerTrait;
  use StringTranslationTrait;

  public function __construct(protected StateInterface $state) {}

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container): static {
    $form = new static($container->get('state'));
    $form->setMessenger($container->get('messenger'));
    $form->setStringTranslation($container->get('string_translation'));

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'log_cache_tags_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $form['log_invalidated_tags'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Log the invalidated cache tags'),
      '#default_value' => $this->state->get('log_cache_tags_log_invalidated_tags', FALSE),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state): void {
    // Validation is not necessary.
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $this->state->set('log_cache_tags_log_invalidated_tags', $form_state->getValue('log_invalidated_tags'));

    $this->messenger()->addStatus($this->t('The settings have been saved.'));
  }

}
